#include <sys/types.h>
#include <sys/resource.h>
#include <sys/param.h>

#include <signal.h>
#include <syslog.h>
#include <stdlib.h>
#include <unistd.h>
#include <login_cap.h>
#include <bsd_auth.h>
#include <stdio.h>
#include <string.h>
#include <pwd.h>
#include <err.h>
#include <util.h>

#include <fprint.h>

#define FINGER_MIN	1
#define FINGER_MAX	10

const char *fingernames[] = {
	[LEFT_THUMB] = "left thumb",
	[LEFT_INDEX] = "left index",
	[LEFT_MIDDLE] = "left middle",
	[LEFT_RING] = "left ring",
	[LEFT_LITTLE] = "left little",
	[RIGHT_THUMB] = "right thumb",
	[RIGHT_INDEX] = "right index",
	[RIGHT_MIDDLE] = "right middle",
	[RIGHT_RING] = "right ring",
	[RIGHT_LITTLE] = "right little",
};

struct fp_dscv_dev *discover_device(struct fp_dscv_dev **);
